@@ -260,7 +260,7 @@ module Capybara
     #
     def current_driver
       if threadsafe
-        Thread.current['capybara_current_driver']
+        Thread.current.thread_variable_get :capybara_current_driver
       else
         @current_driver
       end || default_driver
@@ -269,7 +269,7 @@ module Capybara
 
     def current_driver=(name)
       if threadsafe
-        Thread.current['capybara_current_driver'] = name
+        Thread.current.thread_variable_set :capybara_current_driver, name
       else
         @current_driver = name
       end
@@ -336,7 +336,8 @@ module Capybara
     #
     def session_name
       if threadsafe
-        Thread.current['capybara_session_name'] ||= :default
+        Thread.current.thread_variable_get(:capybara_session_name) ||
+          Thread.current.thread_variable_set(:capybara_session_name, :default)
       else
         @session_name ||= :default
       end
@@ -344,7 +345,7 @@ module Capybara
 
     def session_name=(name)
       if threadsafe
-        Thread.current['capybara_session_name'] = name
+        Thread.current.thread_variable_set :capybara_session_name, name
       else
         @session_name = name
       end
@@ -424,7 +425,7 @@ module Capybara
 
     def specified_session
       if threadsafe
-        Thread.current['capybara_specified_session']
+        Thread.current.thread_variable_get :capybara_specified_session
       else
         @specified_session ||= nil
       end
@@ -432,7 +433,7 @@ module Capybara
 
     def specified_session=(session)
       if threadsafe
-        Thread.current['capybara_specified_session'] = session
+        Thread.current.thread_variable_set :capybara_specified_session, session
       else
         @specified_session = session
       end
